@@ -9,7 +9,7 @@ use actix_web::{web::Data, App, HttpServer};
 use std::{
     env::set_current_dir,
     fs::{canonicalize, read_to_string},
-    io::{Error, Result},
+    io::{Error, ErrorKind, Result},
     path::Path,
 };
 use temp_dir::TempDir;
@@ -35,7 +35,7 @@ where
     P: AsRef<Path>,
 {
     set_current_dir(path.as_ref())?;
-    let temp = TempDir::new().map_err(|e| Error::new(e.kind(), e.to_string()))?;
+    let temp = TempDir::new().map_err(|s| Error::new(ErrorKind::PermissionDenied, s))?;
     // Expand Reveal.js
     extract(temp.path()).await?;
     // Start server
@@ -57,7 +57,7 @@ where
         reload: edit,
     });
     HttpServer::new(move || {
-        let mut app = App::new()
+        let app = App::new()
             .app_data(cache.clone())
             .app_data(Data::new(ServerMonitor::new(cache.project.clone())))
             .service(site::index)
@@ -66,11 +66,10 @@ where
             .service(site::watermark)
             .service(edit_mode::ws_index)
             .service(Files::new("/static", &archive));
-        for asset in &assets {
-            let name = format!("/{:?}", asset.file_name().unwrap());
-            app = app.service(Files::new(&name, asset));
-        }
-        app
+        assets.iter().fold(app, |app, asset| {
+            let name = asset.strip_prefix(".").unwrap_or(asset).to_str().unwrap();
+            app.service(Files::new(name, asset))
+        })
     })
     .bind(("localhost", port))?
     .run()
